/**
 * @file
 * @brief Functions used in Pandemonium.
**/

#ifndef LEVPAND_H
#define LEVPAND_H

void init_pandemonium();

#endif
